==> haskell-servant-client-0.20.3.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client
version:              0.20.3.0
visibility:           public
id:                   servant-client-0.20.3.0-FL6ih1rjS5a75zHUoW4Qbq
key:                  servant-client-0.20.3.0-FL6ih1rjS5a75zHUoW4Qbq
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.
    .
    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  8d358fe136d3596d0222e74be9aa7c65
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20.3.0-FL6ih1rjS5a75zHUoW4Qbq
depends:
    base-4.17.2.1 base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    exceptions-0.10.5 http-client-0.7.19-2IAKaL0RajRLDWsZpaLmo9
    http-media-0.8.1.1-dduLhl1Bxp9vxCFPCMX8i
    http-types-0.12.4-JKUCrzdlATTa7w8tKVNt1
    kan-extensions-5.2.7-5TNadmEhpvk84V1hzzcFfj
    monad-control-1.0.3.1-GYvvySxcDDsKr3A3afhWG mtl-2.2.2
    semigroupoids-6.0.1-KCNtGml05AHAYKR3WNsoxY
    servant-0.20.3.0-JCgjuX80OYWHPEbYupKjZl
    servant-client-core-0.20.3.0-3M2dMs6uSd8BzjFQqNChyD stm-2.5.1.0
    time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-7u55LZmMXS5CMak7FcNNxB

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-client-0.20.3.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client
version:              0.20.3.0
visibility:           public
id:                   servant-client-0.20.3.0-JmrNLjp9QBY4xsJUyfkGVk
key:                  servant-client-0.20.3.0-JmrNLjp9QBY4xsJUyfkGVk
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.
    .
    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  54c1046b494cbf37838635655bbb187c
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-client-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20.3.0-JmrNLjp9QBY4xsJUyfkGVk
depends:
    base-4.17.2.1 base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    exceptions-0.10.5 http-client-0.7.19-68a6qtEv6rj7VpzBTCDGAi
    http-media-0.8.1.1-AyrZcN4Ex41BlPFB4Vjoep
    http-types-0.12.4-D9QL6TIrURkF1xQ74r64OS
    kan-extensions-5.2.7-7CL43zZNCYG1YuP4Au1eD9
    monad-control-1.0.3.1-2Iv7Pom7CbfFvXjbGMwD3h mtl-2.2.2
    semigroupoids-6.0.1-EK4OyRUgfSmL7SZF8dhZKf
    servant-0.20.3.0-GOCUL0U1XwRKlIC4KVIgSx
    servant-client-core-0.20.3.0-3D78SQKAnOaEJvzRSpzVSs stm-2.5.1.0
    time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-K564i6wkEzg7I3CnBbSftj

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
